@@ -14,6 +14,7 @@ const https = require('https');
 const extractZip = require('extract-zip');
 const { getChromeVersion } = require('@testim/chrome-version');
 const HttpsProxyAgent = require('https-proxy-agent');
+const getProxyForUrl = require("proxy-from-env").getProxyForUrl;
 
 const skipDownload = process.env.npm_config_chromedriver_skip_download || process.env.CHROMEDRIVER_SKIP_DOWNLOAD;
 if (skipDownload === 'true') {
@@ -81,7 +82,7 @@ function validatePlatform() {
       process.exit(1);
     }
   } else if (thePlatform === 'darwin' || thePlatform === 'freebsd') {
-    if (process.arch === 'x64') {
+    if (process.arch === 'x64' || process.arch === 'arm64') {
       thePlatform = 'mac64';
     } else {
       console.log('Only Mac 64 bits supported.');
@@ -177,9 +178,8 @@ function getRequestOptions(downloadPath) {
   const options = { url: downloadPath, method: "GET" };
   const urlParts = url.parse(downloadPath);
   const isHttps = urlParts.protocol === 'https:';
-  const proxyUrl = isHttps
-    ? process.env.npm_config_https_proxy
-    : (process.env.npm_config_proxy || process.env.npm_config_http_proxy);
+  const proxyUrl = getProxyForUrl(downloadPath);
+
   if (proxyUrl) {
     const proxyUrlParts = url.parse(proxyUrl);
     options.proxy = {
@@ -250,7 +250,7 @@ async function requestBinary(requestOptions, filePath) {
   const outFile = fs.createWriteStream(filePath);
   let response;
   try {
-    response = await axios.create(requestOptions)({ responseType: 'stream' });
+    response = await axios({ responseType: 'stream', ...requestOptions });
   } catch (error) {
     if (error && error.response) {
       if (error.response.status)
@@ -297,7 +297,7 @@ async function extractDownload(dirToExtractTo) {
 }
 
 async function copyIntoPlace(originPath, targetPath) {
-  await del(targetPath);
+  await del(targetPath, { force: true });
   console.log("Copying to target path", targetPath);
   fs.mkdirSync(targetPath);
 
